@@ -721,7 +721,7 @@ xt::pytensor<float,2> LSDDEM_xtensor::get_chi_raster_all(float m_over_n, float A
   std::array<size_t,2> shape = {size_t(nrows),size_t(ncols)};
   xt::xtensor<float,2> output(shape);
 
-  LSDRaster all_chi = FlowInfo.get_upslope_chi_from_all_baselevel_nodes(m_over_n, A_0, area_threshold);
+  LSDRaster all_chi = FlowInfo.get_upslope_chi_from_all_baselevel_nodes(m_over_n, A_0, area_threshold, DrainageArea);
 
   for(size_t i=0;i<nrows;i++)
   for(size_t j=0;j<ncols;j++)
@@ -1163,7 +1163,7 @@ void LSDDEM_xtensor::calculate_movern_disorder(float start_movern, float delta_m
       std::cout << "Disorder movern for theta=" << movern[i] << " ..." << std::endl;
 
     // recalculating chi for this movern
-    LSDRaster this_chi = FlowInfo.get_upslope_chi_from_all_baselevel_nodes(movern[i], A_0, area_threshold);
+    LSDRaster this_chi = FlowInfo.get_upslope_chi_from_all_baselevel_nodes(movern[i], A_0, area_threshold, DrainageArea);
     ChiTool_disorder.update_chi_data_map(FlowInfo, this_chi); // updating the chitool object
 
 
