@@ -423,6 +423,8 @@ class LSDFlowInfo
   int get_NDataNodes () const          { return NDataNodes; }
   /// @return Vector of all base level nodes.
   vector<int> get_BaseLevelNodeList () { return BaseLevelNodeList; }
+  /// @return get the number of baselevel nodes
+  int get_NBaseLevelNodes () { return int( BaseLevelNodeList.size() );}
 
   /// @return donor stack vector (depth first search sequence of nodes)
   vector <int> get_donorStack() const { return DonorStackVector; }
@@ -711,6 +713,16 @@ class LSDFlowInfo
   ///@date 19/11/2019
   LSDRaster upslope_variable_accumulator_v3(LSDRaster& accum_raster);
 
+  ///@brief This function returns the upslope average value of 
+  /// some raster bassed on the flow info
+  ///@detail Uses the stack vector to get the accumulation
+  ///@param A raster that contains the variable to be averaged (e.g., precipitation)
+  ///@return A raster containing the uplsope average
+  ///@author SMM
+  ///@date 25/06/2021
+  LSDRaster upslope_average(LSDRaster& accum_raster);
+
+
   ///@brief This function tests whether one node is upstream of another node
   ///@param current_node
   ///@param test_node The node which we want to test whether it is upstream or not
@@ -1532,6 +1544,11 @@ void get_nodeindices_from_csv(string csv_filename, vector<int>& NIs, vector<floa
   /// @date 11/01/2021
   vector<bool> internal_nodes(vector<int> node_list);
 
+  /// @brief This takes a node and a vector of nodes and finds the nearest node in the vector to the target node.
+  /// @author FJC
+  /// @date 04/06/21
+  int find_nearest_node_in_vector(int target_node, vector<int> node_vector);
+
   /// @brief Find the elevation difference between the channel and surrounding pixels using the
   /// swath tool.
   /// @return raster of channel relief.
