@@ -140,11 +140,13 @@ vector<string> DriverIngestor(int nNumberofArgs,char *argv[])
   path_and_file.push_back(file_name);
 
   if (path_and_file[0] == "-h" || path_and_file[0] == "--h" || 
+      path_and_file[0] == "-H" || path_and_file[0] == "--H" || 
       path_and_file[0] == "--help" || path_and_file[0] == "-help"  ||
       path_and_file[0] == "help" || path_and_file[0] == "Help"  ||
       path_and_file[0] == "HELP" || path_and_file[0] == "-help"  ||
       path_and_file[0] == "-WTF" ||
       path_and_file[1] == "-h" || path_and_file[1] == "--h" || 
+      path_and_file[0] == "-H" || path_and_file[0] == "--H" || 
       path_and_file[1] == "--help" || path_and_file[1] == "-help"  ||
       path_and_file[1] == "help" || path_and_file[1] == "Help"  ||
       path_and_file[1] == "HELP" || path_and_file[1] == "-help"  ||
@@ -162,6 +164,56 @@ vector<string> DriverIngestor(int nNumberofArgs,char *argv[])
     ofs.close();
   }
 
+
+  if (path_and_file[0] == "-c" || path_and_file[0] == "--c" || 
+      path_and_file[0] == "--C" || path_and_file[0] == "-C"  ||
+      path_and_file[0] == "cite" || path_and_file[0] == "Cite"  ||
+      path_and_file[0] == "-cite" || path_and_file[0] == "-Cite"  ||
+      path_and_file[0] == "--cite" || path_and_file[0] == "--Cite"  ||
+      path_and_file[0] == "citation" || path_and_file[0] == "Citation"  ||
+      path_and_file[0] == "-citation" || path_and_file[0] == "-Citation"  ||
+      path_and_file[0] == "--citation" || path_and_file[0] == "--Citation"  ||
+      path_and_file[1] == "-c" || path_and_file[0] == "--c" || 
+      path_and_file[1] == "--C" || path_and_file[0] == "-C"  ||
+      path_and_file[1] == "cite" || path_and_file[0] == "Cite"  ||
+      path_and_file[1] == "-cite" || path_and_file[0] == "-Cite"  ||
+      path_and_file[1] == "--cite" || path_and_file[0] == "--Cite"  ||
+      path_and_file[1] == "citation" || path_and_file[0] == "Citation"  ||
+      path_and_file[1] == "-citation" || path_and_file[0] == "-Citation"  ||
+      path_and_file[1] == "--citation" || path_and_file[0] == "--Citation" )
+  {
+    cout << "You have chosen to print the citation information. " << endl;
+    path_and_file[0] = "./";
+    path_and_file[1] = "lsdtt_citation.txt";
+
+    ofstream ofs;
+    ofs.open("./lsdtt_citation.txt");
+    ofs << "# The user has asked for a citation. " << endl;
+    ofs.close();
+  }
+
+  if (path_and_file[0] == "-v" || path_and_file[0] == "--v" || 
+      path_and_file[0] == "-V" || path_and_file[0] == "--V"  ||
+      path_and_file[0] == "version" || path_and_file[0] == "Version"  ||
+      path_and_file[0] == "-version" || path_and_file[0] == "-Version"  ||
+      path_and_file[0] == "--version" || path_and_file[0] == "--Version"  ||
+      path_and_file[1] == "-v" || path_and_file[0] == "--v" || 
+      path_and_file[1] == "-V" || path_and_file[0] == "--V"  ||
+      path_and_file[1] == "version" || path_and_file[0] == "Version"  ||
+      path_and_file[1] == "-version" || path_and_file[0] == "-Version"  ||
+      path_and_file[1] == "--version" || path_and_file[0] == "--Version" )
+  {
+    cout << "You have chosen to print the version. " << endl;
+    path_and_file[0] = "./";
+    path_and_file[1] = "lsdtt_version.txt";
+
+    ofstream ofs;
+    ofs.open("./lsdtt_version.txt");
+    ofs << "# The user has asked for the version. " << endl;
+    ofs.close();
+  }
+
+
   return path_and_file;
 
 }
@@ -216,8 +268,9 @@ void LSDParameterParser::create(string PathName, string FileName)
 void LSDParameterParser::force_bil_extension()
 {
   cout << "===============================" << endl;
-  cout << "WARNING!!! This program requires georeferencing so only bil format" << endl;
+  cout << "WARNING!!! This program requires georeferencing so only ENVI bil format" << endl;
   cout << "Topographic data will be allowed!!" << endl;
+  cout << "This is not the same as ESRI bil. In gdal use -of ENVI to ouput to ENVI bil" << endl;
   cout << "===============================" << endl;
   dem_read_extension = "bil";
   dem_write_extension = "bil";
@@ -415,10 +468,7 @@ void LSDParameterParser::parse_file_IO()
     }
     found_cheads = true;
   }
-  else
-  {
-    cout << "I didn't find CHeads_file in the parameter map" << endl;
-  }
+
 
 
   if(parameter_map.find("channel heads fname") != parameter_map.end())
@@ -537,7 +587,7 @@ void LSDParameterParser::parse_all_parameters(map<string,float> default_map_f,
 }
 
 
-void LSDParameterParser::print_help(map< string, vector<string> > help_map, string help_prefix)
+void LSDParameterParser::print_help(map< string, vector<string> > help_map, string help_prefix, string version, string citation)
 {
   
   // Open the help file
@@ -549,6 +599,7 @@ void LSDParameterParser::print_help(map< string, vector<string> > help_map, stri
   vector<string> this_string_vec;
 
   help_ofs << "name,type,default,description,guidance" << endl;
+  help_ofs <<"version,"<< version << ",citation,"<< citation << ", please also look at statements printed by code for citations to specific routines." << endl;
 
   // get the parameters
   vector<string> these_keys = extract_keys(parameters_read_map);
@@ -854,7 +905,7 @@ void LSDParameterParser::check_boundary_conditions()
 {
   if( int(boundary_conditions.size()) != 4)
   {
-    cout << "Boundary conditions not assigned! Defaulting to no flux."  << endl;
+    //cout << "Boundary conditions not assigned! Defaulting to no flux."  << endl;
     vector<string> temp_bc(4);
     for (int i = 0; i< 4; i++)
     {
@@ -863,10 +914,10 @@ void LSDParameterParser::check_boundary_conditions()
     boundary_conditions = temp_bc;
   }
 
-  for (int i =0; i< 4; i++)
-  {
-    cout << "Boundary["<<i<<"]: "<<boundary_conditions[i]<< endl;
-  }
+  //for (int i =0; i< 4; i++)
+  //{
+  //  cout << "Boundary["<<i<<"]: "<<boundary_conditions[i]<< endl;
+  //}
 }
 //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 
@@ -882,8 +933,8 @@ void LSDParameterParser::check_file_extensions_and_paths()
   if (dem_read_extension != "asc"  && dem_read_extension != "flt" && dem_read_extension != "bil" &&
       dem_write_extension != "asc"  && dem_write_extension != "flt" && dem_write_extension != "bil")
   {
-    cout << "LSDParameterParser Raster file extension not assigned! Defaulting to bil format." << endl;
-    cout << "You entered: " << dem_read_extension << "!" <<endl;
+    //cout << "LSDParameterParser Raster file extension not assigned! Defaulting to bil format." << endl;
+    //cout << "You entered: " << dem_read_extension << "!" <<endl;
     dem_read_extension = "bil";
     dem_write_extension = "bil";
   }
@@ -891,7 +942,7 @@ void LSDParameterParser::check_file_extensions_and_paths()
   {
     if (dem_read_extension != "asc"  && dem_read_extension != "flt" && dem_read_extension != "bil")
     {
-      cout << "DEM read extension not assigned, defaulting to write extension." << endl;
+      //cout << "DEM read extension not assigned, defaulting to write extension." << endl;
       dem_read_extension = dem_write_extension;
     }
     else
@@ -944,8 +995,8 @@ void LSDParameterParser::check_file_extensions_and_paths()
 
   cout << "The full read fname is:\n " << read_path+read_fname << endl;
   cout << "The full write fname is:\n " << write_path+write_fname << endl;
-  cout << "The read and write extensions are: " << dem_read_extension
-       << " " << dem_write_extension << endl;
+  //cout << "The read and write extensions are: " << dem_read_extension
+  //     << " " << dem_write_extension << endl;
 
 }
 //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
