@@ -403,10 +403,13 @@ void LSDRasterMaker::impose_channels(LSDSpatialCSVReader& source_points_data)
 ////------------------------------------------------------------------------------
 void LSDRasterMaker::buffer_basin_to_single_outlet(LSDSpatialCSVReader& source_points_data, float slope)
 {
+  
   string column_name = "elevation(m)";
 
-  float elev_diff = DataResolution*sqrt(2)*slope;
+  float elev_diff = 10;  //DataResolution*sqrt(2)*slope;
 
+  vector<int> min_elev_nd_rows;
+  vector<int> min_elev_nd_cols;
 
   Array2D<float> zeta=RasterData.copy();
   Array2D<float> old_zeta = RasterData.copy();
@@ -416,22 +419,28 @@ void LSDRasterMaker::buffer_basin_to_single_outlet(LSDSpatialCSVReader& source_p
   source_points_data.get_x_and_y_from_latlong(UTME,UTMN);
 
   int min_row,min_col;
+  int rp1,rm1,cp1,cm1;
 
   vector<float> elev;
   if ( UTME.size() == 1)
   {
+    cout << "Only one element!" << endl;
     elev.push_back(0);
   }
   else
   {
-    vector<float> elev = source_points_data.data_column_to_float(column_name);
+    elev = source_points_data.data_column_to_float(column_name);
+    cout << "There are " << elev.size() << " data points" << endl;
   }
 
   // find the minimum elevation
+  int n_elev = int(elev.size());
   float min_elev = 10000000000;
   int node_of_min_elev = 0;
-  for(int i = 0; i< int(elev.size()); i++)
+  cout << "n_elev: " << n_elev << endl;
+  for(int i = 0; i< n_elev; i++)
   {
+    cout << "elev: " << elev[i] << endl;
     if(elev[i] < min_elev)
     {
       min_elev = elev[i];
@@ -439,14 +448,86 @@ void LSDRasterMaker::buffer_basin_to_single_outlet(LSDSpatialCSVReader& source_p
     }
   }
   get_row_and_col_of_a_point(UTME[node_of_min_elev],UTMN[node_of_min_elev],min_row, min_col);
+  cout << "The minimum elevation of the source point is: " << min_elev << " at node: " << node_of_min_elev << endl;
+  cout << "minimum elev in source points is at " << UTME[node_of_min_elev] << " , " << UTMN[node_of_min_elev] << endl;
+
+  // now logic for finding the nodata around the minimum elevation
+  rp1 = min_row+1;
+  if(rp1 == NRows)
+  {
+    rp1 = min_row;
+  }
+  rm1 = min_row-1;
+  if (rm1 == -1)
+  {
+    rm1 = 0;
+  }
+  cp1 = min_col+1;
+  if (cp1 == NCols)
+  {
+    cp1 = min_col;
+  }
+  cm1 = min_col-1;
+  if (cm1 == -1)
+  {
+    cm1 = 0;
+  }   
+ 
+  // now search all adjacent nodes
+  if ( old_zeta[rp1][cp1] == NoDataValue)
+  {
+    cout << "Buffering, found ndv" << endl;
+    min_elev_nd_rows.push_back(rp1);
+    min_elev_nd_cols.push_back(cp1);
+  }
+  if ( old_zeta[rp1][min_col] == NoDataValue)
+  {
+    cout << "Buffering, found ndv" << endl;
+    min_elev_nd_rows.push_back(rp1);
+    min_elev_nd_cols.push_back(min_col);
+  }
+  if ( old_zeta[rp1][cm1] == NoDataValue)
+  {
+    cout << "Buffering, found ndv" << endl;
+    min_elev_nd_rows.push_back(rp1);
+    min_elev_nd_cols.push_back(cm1);
+  }
+  if ( old_zeta[min_row][cp1] == NoDataValue)
+  {
+    cout << "Buffering, found ndv" << endl;
+    min_elev_nd_rows.push_back(min_row);
+    min_elev_nd_cols.push_back(cp1);
+  }
+  if ( old_zeta[min_row][cm1] == NoDataValue)
+  {
+    cout << "Buffering, found ndv" << endl;
+    min_elev_nd_rows.push_back(min_row);
+    min_elev_nd_cols.push_back(cm1);
+  }
+  if ( old_zeta[rm1][cp1] == NoDataValue)
+  {
+    cout << "Buffering, found ndv" << endl;
+    min_elev_nd_rows.push_back(rm1);
+    min_elev_nd_cols.push_back(cm1);
+  }
+  if ( old_zeta[rm1][min_col] == NoDataValue)
+  {
+    cout << "Buffering, found ndv" << endl;
+    min_elev_nd_rows.push_back(rm1);
+    min_elev_nd_cols.push_back(min_col);
+  }
+  if ( old_zeta[rm1][cm1] == NoDataValue)
+  {
+    cout << "Buffering, found ndv" << endl;
+    min_elev_nd_rows.push_back(rm1);
+    min_elev_nd_cols.push_back(cm1);
+  }     
 
   // Now crinkle up the side
-  int rp1,rm1,cp1,cm1;
   for(int row = 0; row< NRows; row++)
   {
     for(int col = 0; col<NCols; col++)
     {
-
       if (row == min_row && col == min_col)
       {
         cout << "Found the minimum elevation" << endl;
@@ -515,6 +596,13 @@ void LSDRasterMaker::buffer_basin_to_single_outlet(LSDSpatialCSVReader& source_p
     }
   }
 
+  // now return the data around the minimum value to nodata
+  for (int i = 0; i< int(min_elev_nd_rows.size()); i++)
+  {
+    //cout << "yoyoma" << endl;
+    zeta[ min_elev_nd_rows[i] ][ min_elev_nd_cols[i] ] = NoDataValue;
+  }
+
 
   this->RasterData = zeta.copy();
 
