@@ -50,6 +50,7 @@
 //=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <fstream>
 #include <cmath>
+#include <iomanip>
 #include <iostream>
 #include <map>
 #include <string>
@@ -253,7 +254,7 @@ void LSDSpatialCSVReader::load_csv_data(string filename)
   int longitude_index = -9999;
   for (int i = 0; i<n_headers; i++)
   {
-    cout << "This header is: " << this_string_vec[i] << endl;
+    //cout << "This header is: " << this_string_vec[i] << endl;
     if (this_string_vec[i]== "latitude" || this_string_vec[i] == "Latitude" || this_string_vec[i] == "lat" || this_string_vec[i] == "Lat")
     {
       latitude_index = i;
@@ -617,7 +618,7 @@ vector<double> LSDSpatialCSVReader::data_column_to_double(string column_name)
 // Adds a float to a data column
 void LSDSpatialCSVReader::data_column_add_float(string column_name, float add_value)
 {
-  cout << "Adding " << add_value << " to the column " << column_name << endl;
+  //cout << "Adding " << add_value << " to the column " << column_name << endl;
   vector<string> string_vec = get_data_column(column_name);
   float this_value;
   vector<string> new_string_vec;
@@ -641,6 +642,76 @@ void LSDSpatialCSVReader::data_column_add_float(string column_name, float add_va
   data_map[column_name] = new_string_vec;
 }
 
+
+// Adds a float to a data column
+void LSDSpatialCSVReader::data_column_add_float(string column_name, vector<float> add_value)
+{
+  //cout << "Adding " << add_value << " to the column " << column_name << endl;
+  vector<string> string_vec = get_data_column(column_name);
+  float this_value;
+  vector<string> new_string_vec;
+  int N_data_elements = string_vec.size();
+
+  if (N_data_elements != int( add_value.size()))
+  {
+    cout << "Can't add vectors of different size to csv object" << endl;
+    exit(0);
+  }
+
+  if (N_data_elements == 0)
+  {
+    cout << "Couldn't read in the data column. Check the column name!" << endl;
+  }
+  for(int i = 0; i<N_data_elements; i++)
+  {
+
+    this_value = atof(string_vec[i].c_str())+add_value[i];
+
+    //if (i< 10)
+    //{
+    // cout << "Orig: " << atof(string_vec[i].c_str()) << " final " << this_value << endl;
+    //}
+
+    new_string_vec.push_back(to_string(this_value));
+  }
+  data_map[column_name] = new_string_vec;
+}
+
+
+
+
+// Adds a float to a data column
+void LSDSpatialCSVReader::data_column_replace(string column_name, vector<float> new_column)
+{
+  // cout << "Adding " << add_value << " to the column " << column_name << endl;
+  vector<string> string_vec = get_data_column(column_name);
+  float this_value;
+  vector<string> new_string_vec;
+  int N_data_elements = string_vec.size();
+  if (N_data_elements == 0)
+  {
+    cout << "Couldn't read in the data column. Check the column name!" << endl;
+  }
+
+  if (N_data_elements != int(new_column.size()))
+  {
+    cout << "You are trying to replace a data column using a column that is a different size. " << endl;
+    cout << "I'm afraid I can't do that." << endl;
+    cout << "Aborting replace." << endl;
+  }
+  else
+  {
+    for(int i = 0; i<N_data_elements; i++)
+    {
+      new_string_vec.push_back(to_string(new_column[i]));
+    }
+    data_map[column_name] = new_string_vec;
+  }
+  
+
+}
+
+
 // Multiplies values in a data column
 void LSDSpatialCSVReader::data_column_multiply_float(string column_name, float multiply_value)
 {
@@ -681,7 +752,7 @@ void LSDSpatialCSVReader::enforce_slope(string fd_column_name, string elevation_
     dist = flow_distance[i]-flow_distance[i+1];
 
     min_elev = dist*min_slope+new_elevation[i+1];
-    //cout << "dist: " << dist << " z[i+1]: " << new_elevation[i+1] << " z[i]: " << elevation[i] << " min_elev: " << min_elev << endl;
+    cout << "dist: " << dist << " z[i+1]: " << new_elevation[i+1] << " z[i]: " << elevation[i] << " min_elev: " << min_elev << endl;
     if (dist < 0 || fabs(dist) >128)
     {
       cout << "There seems to be a big changes in flow distance (greater than a diagonal pixel at 90m resolution" << endl;
@@ -692,7 +763,7 @@ void LSDSpatialCSVReader::enforce_slope(string fd_column_name, string elevation_
     {
       if (elevation[i] < min_elev)
       {
-        //cout << "Found something where I need to increase slope!" << endl;
+        cout << "Found something where I need to increase slope!" << endl;
         new_elevation[i] = min_elev;
       }
       else
@@ -1130,7 +1201,9 @@ vector<int> LSDSpatialCSVReader::get_nodeindices_from_lat_long(LSDFlowInfo& Flow
   for (int i = 0; i < int(X_coords.size()); i++)
   {
     int NodeIndex = FlowInfo.get_node_index_of_coordinate_point(X_coords[i], Y_coords[i]);
-    NIs.push_back(NodeIndex);
+    if (NodeIndex != NoDataValue) {
+      NIs.push_back(NodeIndex);
+    }
   }
 
   return NIs;
@@ -1541,6 +1614,15 @@ void LSDSpatialCSVReader::print_row_and_col_to_csv(string csv_outname)
 void LSDSpatialCSVReader::print_data_to_csv(string csv_outname)
 {
   ofstream outfile;
+
+  // make sure the file has the csv extension
+  string ext_str = ".csv";
+  if (csv_outname.find(ext_str) == std::string::npos) 
+  {
+    csv_outname = csv_outname + ext_str;
+  }
+
+
   outfile.open(csv_outname.c_str());
 
   outfile << "latitude,longitude";
@@ -1841,43 +1923,67 @@ void LSDSpatialCSVReader::interpolate_across_gap(LSDRaster& ThisRaster, string X
       }
       else
       {
+        cout.precision(12);
+
         cout << "There seems to be a gap." << endl;
         gap_counter = gap_counter +1;
 
-        // Store coordinates of node before gap
-        guilty_X_vector.push_back(UTME[i]);
-        guilty_Y_vector.push_back(UTMN[i]);
+        float diff_flowdist;
+        cout << "Flow distance is " << flow_distance[i] << endl;
+        cout << "Next flow distance is " << flow_distance[i+1] << endl;
 
-        for (const auto& kv : get_data_map())
+        diff_flowdist = flow_distance[i] - flow_distance[i+1];
+
+        cout << "Flow distance jump is: " << diff_flowdist << endl;
+
+        if(abs(diff_flowdist) > 200)
         {
-          // cout << "I AM NAME OF COLUMN:" << kv.first << endl;
-          vector<string> this_string_vector = kv.second;
+          cout << "I think we are at the head of a channel, let's ignore this point." << endl;
+        }
 
-          // Converting the vectors to float, adapted from https://stackoverflow.com/questions/35419046/converting-from-vectorstring-to-vectordouble-without-stdstod
-          vector<float> this_float_vector;
-          // iterate over vector and convert each object to float, then add to new float vector
-          for (vector<string>::const_iterator iter = this_string_vector.begin(); iter != this_string_vector.end(); ++iter)
+        else
+        {
+
+          // Store coordinates of node before gap
+          guilty_X_vector.push_back(UTME[i]);
+          guilty_Y_vector.push_back(UTMN[i]);
+
+          for (const auto& kv : get_data_map())
           {
-            string const& element = *iter;
-            // use a stringstream to get a float value:
-            istringstream is(element);
-            float result;
-            is >> result;
+            // cout << "I AM NAME OF COLUMN:" << kv.first << endl;
+            vector<string> this_string_vector = kv.second;
 
-            // add the float value to the result vector:
-            this_float_vector.push_back(result);
+            // Converting the vectors to float, adapted from https://stackoverflow.com/questions/35419046/converting-from-vectorstring-to-vectordouble-without-stdstod
+            vector<float> this_float_vector;
+            // iterate over vector and convert each object to float, then add to new float vector
+            for (vector<string>::const_iterator iter = this_string_vector.begin(); iter != this_string_vector.end(); ++iter)
+            {
+              string const& element = *iter;
+              // use a stringstream to get a float value:
+              // istringstream is(element);
+              // float result;
+              // is >> result;
+              std::ostringstream out;
+              out << std::setprecision(12) << std::stof(element);
+              float precise = std::stof(out.str());
+
+
+
+              // add the float value to the result vector:
+              this_float_vector.push_back(precise);
+            }
+            // cout << "Downstream of gap, " << kv.first << " is " << this_float_vector[i] << endl;
+            // cout << "Upstream of gap, " << kv.first << " is " << this_float_vector[i+1] << endl;
+            // cout << "Let's do a super basic interpolation!" << endl;
+
+            float interpolated_value;
+            interpolated_value = this_float_vector[i] + ((this_float_vector[i+1] - this_float_vector[i])/2);
+            // cout << "Interpolated value of " << kv.first << " is " << interpolated_value << endl;
+            stringstream interpolated_string;
+            interpolated_string.precision(12);
+            interpolated_string << interpolated_value;
+            append_to_col(kv.first, to_string(interpolated_value) ); // previous, outdated version: append_to_col(kv.first, interpolated_string.str());
           }
-          // cout << "Downstream of gap, " << kv.first << " is " << this_float_vector[i] << endl;
-          // cout << "Upstream of gap, " << kv.first << " is " << this_float_vector[i+1] << endl;
-          // cout << "Let's do a super basic interpolation!" << endl;
-
-          float interpolated_value;
-          interpolated_value = this_float_vector[i] + ((this_float_vector[i+1] - this_float_vector[i])/2);
-          // cout << "Interpolated value of " << kv.first << " is " << interpolated_value << endl;
-          stringstream interpolated_string;
-          interpolated_string.precision(9);
-          interpolated_string << interpolated_value;
-          append_to_col(kv.first, interpolated_string.str());
         }
       }
     }
